@@ -3,7 +3,7 @@
 /*                  This file is part of the program and library             */
 /*         SCIP --- Solving Constraint Integer Programs                      */
 /*                                                                           */
-/*  Copyright (c) 2002-2023 Zuse Institute Berlin (ZIB)                      */
+/*  Copyright (c) 2002-2025 Zuse Institute Berlin (ZIB)                      */
 /*                                                                           */
 /*  Licensed under the Apache License, Version 2.0 (the "License");          */
 /*  you may not use this file except in compliance with the License.         */
@@ -1291,7 +1291,8 @@ SCIP_DECL_PRESOLEXEC(presolExecGateextraction)
 
    *result = SCIP_DIDNOTRUN;
 
-#if 0 /* need to include cons_knapsack on top of this file */
+#ifdef SCIP_DISABLED_CODE
+   /* need to include cons_knapsack on top of this file */
    /* check for possible knapsacks that form with a logicor a weak relaxation of an and-constraint
     *
     * the weak relaxation of an and-constraint looks like:
