@@ -3,7 +3,7 @@
 /*                  This file is part of the program and library             */
 /*         SCIP --- Solving Constraint Integer Programs                      */
 /*                                                                           */
-/*  Copyright (c) 2002-2024 Zuse Institute Berlin (ZIB)                      */
+/*  Copyright (c) 2002-2025 Zuse Institute Berlin (ZIB)                      */
 /*                                                                           */
 /*  Licensed under the Apache License, Version 2.0 (the "License");          */
 /*  you may not use this file except in compliance with the License.         */
@@ -954,7 +954,7 @@ SCIP_RETCODE printExpr(
             if( stage == SCIP_EXPRITER_ENTEREXPR )
                SCIPinfoMessage(scip, file, "power(");
             else if( stage == SCIP_EXPRITER_LEAVEEXPR )
-               SCIPinfoMessage(scip, file, ",%g)", exponent);
+               SCIPinfoMessage(scip, file, ",%.15g)", exponent);
             /* if power but not square, then we are no longer quadratic */
             *nqcons = FALSE;
          }
