@@ -3,7 +3,7 @@
 /*                  This file is part of the program and library             */
 /*         SCIP --- Solving Constraint Integer Programs                      */
 /*                                                                           */
-/*  Copyright (c) 2002-2024 Zuse Institute Berlin (ZIB)                      */
+/*  Copyright (c) 2002-2025 Zuse Institute Berlin (ZIB)                      */
 /*                                                                           */
 /*  Licensed under the Apache License, Version 2.0 (the "License");          */
 /*  you may not use this file except in compliance with the License.         */
@@ -819,7 +819,12 @@ SCIP_RETCODE hashExpr(
 #undef SCIPgetExprhdlrPower
 #endif
 
-/** creates the handler for an expression handler and includes it into SCIP */
+/** creates the handler for an expression handler and includes it into SCIP
+ *
+ *  @pre This method can be called if SCIP is in one of the following stages:
+ *       - \ref SCIP_STAGE_INIT
+ *       - \ref SCIP_STAGE_PROBLEM
+ */
 SCIP_RETCODE SCIPincludeExprhdlr(
    SCIP*                 scip,               /**< SCIP data structure */
    SCIP_EXPRHDLR**       exprhdlr,           /**< buffer where to store created expression handler */
@@ -834,6 +839,8 @@ SCIP_RETCODE SCIPincludeExprhdlr(
    assert(scip->mem != NULL);
    assert(exprhdlr != NULL);
 
+   SCIP_CALL( SCIPcheckStage(scip, "SCIPincludeExprhdlr", TRUE, TRUE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE) );
+
    SCIP_CALL( SCIPexprhdlrCreate(scip->mem->setmem, exprhdlr, name, desc, precedence, eval, data) );
    assert(*exprhdlr != NULL);
 
@@ -1366,12 +1373,12 @@ SCIP_RETCODE SCIPcopyExpr(
  * a `Term` is a product of `Factors` and an `Expression` is a sum of `Terms`.
  *
  * The actual definition:
- * <pre>
+ * ```
  * Expression -> ["+" | "-"] Term { [ ("+" | "-" | "number *") Term | ("number" <varname>) ] }
  * Term       -> Factor { ("*" | "/" ) Factor }
  * Factor     -> Base [ "^" "number" | "^(" "number" ")" ]
  * Base       -> "number" | "<varname>" | "(" Expression ")" | Op "(" OpExpression ")
- * </pre>
+ * ```
  * where `[a|b]` means `a` or `b` or none, `(a|b)` means `a` or `b`, `{a}` means 0 or more `a`.
  *
  * Note that `Op` and `OpExpression` are undefined.
