@@ -3,7 +3,7 @@
 /*                  This file is part of the program and library             */
 /*         SCIP --- Solving Constraint Integer Programs                      */
 /*                                                                           */
-/*  Copyright (c) 2002-2024 Zuse Institute Berlin (ZIB)                      */
+/*  Copyright (c) 2002-2025 Zuse Institute Berlin (ZIB)                      */
 /*                                                                           */
 /*  Licensed under the Apache License, Version 2.0 (the "License");          */
 /*  you may not use this file except in compliance with the License.         */
@@ -867,15 +867,15 @@ Test(change, testrowmethods)
 Test(change, testcolmethods)
 {
    /* problem data */
-   SCIP_Real obj[5] = { 1.0, 1.0, 1.0, 1.0, 1.0 };
    SCIP_Real lhs[5] = { -1.0, -SCIPlpiInfinity(lpi), 0.0, -SCIPlpiInfinity(lpi), 0.0 };
    SCIP_Real rhs[5] = { 10.0, SCIPlpiInfinity(lpi), SCIPlpiInfinity(lpi), 29.0, 0.0 };
    int ncolsbefore, ncolsafter;
    int nrowsbefore, nrowsafter;
+   SCIP_Real obj[6] = { 1.0, 1.0, 1.0, 1.0, 1.0, 1.0 };
    SCIP_Real lbvals[6] = { -SCIPlpiInfinity(lpi), -1.0, -3e-10, 0.0, 1.0, 3e10 };
    SCIP_Real ubvals[6] = { -1.0, -3e-10, 0.0, 1.0, 3e10, SCIPlpiInfinity(lpi) };
-   SCIP_Real   vals[10] = { 1.0, 5.0, -1.0, 3e5, 2.0, 1.0, 20, 10, -1.9, 1e-2 };
-   int  nnonzs[6]  = { 1, 10, -1, 6, -1 };
+   SCIP_Real vals[10] = { 1.0, 5.0, -1.0, 3e5, 2.0, 1.0, 20, 10, -1.9, 1e-2 };
+   int nnonzs[5]  = { 1, 10, -1, 6, -1 };
    int begvals[6]  = { 0, 2, 3, 5, 8, 9 };
    int indvals[10] = { 0, 1, 3, 2, 1, 1, 2, 4, 0, 3 };
 
@@ -923,6 +923,7 @@ Test(change, testcolmethods)
          int newind[100];
          int newnnonz;
 
+         assert( nnonz > 0 );
          assert( ncols < 100 );
          for( j = 0; j < ncols; j++ )
          {
